@@ -4,8 +4,8 @@
 ##   swappolube  -  Configuration UI for the swappolube script ##
 #################################################################
 
-#Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-#Version: 0.2.0-2
+##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
+##Version: 0.2.0-3
 
 import os
 import sys
@@ -117,12 +117,12 @@ class MyMainWindow(QtGui.QMainWindow):
              msg += "Distributed under GPL ver. 2"
              QMessageBox.about(self, "Credits - SWAPPOLUBE Editor", msg)
  
-        def doDeleteTunings(self):
+        def doDeleteTunings(self): ##FIXME: check if file was deleted!!
              os.system('echo "rm /etc/event.d/tuning"|root')
              message = 'The tuning file has been removed from the boot sequence.\nOn next reboot, the system will start with its default configuration.'
              showMessage(message)
 
-        def doSetCurrent(self):
+        def doSetCurrent(self): ##FIXME: separate reading and setting to two methods!!!
              """Set current values in the GUI"""
              
              ##Set values for enable/disable   
@@ -140,36 +140,36 @@ class MyMainWindow(QtGui.QMainWindow):
 
              ##Set Values for checkboxes
              
-             if os.popen('cat /proc/sys/vm/oom_kill_allocating_task').read() == '1\n':
+             if os.popen('cat /proc/sys/vm/oom_kill_allocating_task').read().strip('\n') == '1':
                 self.ui.checkBoxKillAllocatingTask.setChecked(True)
              else:
                 self.ui.checkBoxKillAllocatingTask.setChecked(False)
 
-             if os.popen('cat /proc/sys/net/ipv4/tcp_timestamps').read() == '1\n':
+             if os.popen('cat /proc/sys/net/ipv4/tcp_timestamps').read().strip('\n') == '1':
                self.ui.checkBoxTCPTimestamps.setChecked(True)
              else:
                self.ui.checkBoxTCPTimestamps.setChecked(False)
 
-             if os.popen('cat /proc/sys/net/ipv4/tcp_no_metrics_save').read() == '1\n':
+             if os.popen('cat /proc/sys/net/ipv4/tcp_no_metrics_save').read().strip('\n') == '1':
                self.ui.checkBoxTCPNoMetricsSave.setChecked(True)
              else:
                self.ui.checkBoxTCPNoMetricsSave.setChecked(False)
 
              ##Set values for lineEdits
-             LaptopMode = os.popen('cat /proc/sys/vm/laptop_mode').read()
-             DirtyRatio = os.popen('cat /proc/sys/vm/dirty_ratio').read()
-             Swappiness = os.popen('cat /proc/sys/vm/swappiness').read()
-             DirtyBGDRatio = os.popen('cat /proc/sys/vm/dirty_background_ratio').read()
-             VFSCachePressure = os.popen('cat /proc/sys/vm/vfs_cache_pressure').read()
-             PageCluster = os.popen('cat /proc/sys/vm/page-cluster').read()
-             DirtyWritebackCentisecs = os.popen('cat /proc/sys/vm/dirty_writeback_centisecs').read()
-             DirtyExpireCentisecs = os.popen('cat /proc/sys/vm/dirty_expire_centisecs').read()
+             LaptopMode = os.popen('cat /proc/sys/vm/laptop_mode').read().strip('\n')
+             DirtyRatio = os.popen('cat /proc/sys/vm/dirty_ratio').read().strip('\n')
+             Swappiness = os.popen('cat /proc/sys/vm/swappiness').read().strip('\n')
+             DirtyBGDRatio = os.popen('cat /proc/sys/vm/dirty_background_ratio').read().strip('\n')
+             readVFSCachePressure = os.popen('cat /proc/sys/vm/vfs_cache_pressure').read().strip('\n')
+             PageCluster = os.popen('cat /proc/sys/vm/page-cluster').read().strip('\n')
+             DirtyWritebackCentisecs = os.popen('cat /proc/sys/vm/dirty_writeback_centisecs').read().strip('\n')
+             DirtyExpireCentisecs = os.popen('cat /proc/sys/vm/dirty_expire_centisecs').read().strip('\n')
              
              self.ui.lineLaptopMode.setText("%s" % LaptopMode)
              self.ui.lineDirtyRatio.setText("%s" % DirtyRatio)
              self.ui.lineSwappiness.setText("%s" % Swappiness)
              self.ui.lineDirtyBGDRatio.setText("%s" % DirtyBGDRatio)  
-             self.ui.lineVFSCachePressure.setText("%s" % VFSCachePressure)
+             self.ui.lineVFSCachePressure.setText("%s" % readVFSCachePressure)
              self.ui.linePageCluster.setText("%s" % PageCluster)
              self.ui.lineDirtyWritebackCentisecs.setText("%s" % DirtyWritebackCentisecs )
              self.ui.lineDirtyExpireCentisecs.setText("%s" % DirtyExpireCentisecs)
@@ -177,7 +177,7 @@ class MyMainWindow(QtGui.QMainWindow):
              message = 'The CURRENT configuration options are shown.'
              showQuickMessage(message)
 
-        def doSetProposed(self):
+        def doSetProposed(self): ##FIXME: outsourse proposed values to a file!!!
              """ Set default values in the GUI """
              
              ##Set values for enable/disable   
@@ -216,7 +216,8 @@ class MyMainWindow(QtGui.QMainWindow):
              
              message = 'Please wait. Update in progress..'
              showQuickMessage(message)
-
+             
+             ##Read GUI.
              DirtyRatio = self.ui.lineDirtyRatio.text()
              Swappiness = self.ui.lineSwappiness.text()
              DirtyBGDRatio = self.ui.lineDirtyBGDRatio.text()  
@@ -224,6 +225,7 @@ class MyMainWindow(QtGui.QMainWindow):
              DirtyExpireCentisecs = self.ui.lineDirtyExpireCentisecs.text()
              DirtyWritebackCentisecs = self.ui.lineDirtyWritebackCentisecs.text()
              LaptopMode = self.ui.lineLaptopMode.text()
+             VFSCachePressure = self.ui.lineVFSCachePressure.text()
                 
              if  self.ui.checkBoxKillAllocatingTask.isChecked() == True:
                 KillAllocatingTask = '1'
@@ -237,8 +239,8 @@ class MyMainWindow(QtGui.QMainWindow):
                 TCPNoMetricsSave = '1'
              else:
                 TCPNoMetricsSave = '0'
-           
-             #Update the values.
+              
+             ##Update the values.
              if self.ui.radioKillAllocatingTask.isChecked() == True:
                os.system('echo "echo \"%s\" > /proc/sys/vm/oom_kill_allocating_task"|root' % KillAllocatingTask) 
              if self.ui.radioPageCluster.isChecked() == True:
@@ -260,7 +262,7 @@ class MyMainWindow(QtGui.QMainWindow):
              if self.ui.radioDirtyBGDRatio.isChecked() == True:
                os.system('echo "echo \"%s\" > /proc/sys/vm/dirty_background_ratio"|root' % DirtyBGDRatio) 
              if self.ui.radioVFSCachePressure.isChecked() == True:
-               os.system('echo "echo \"%s\" > /proc/sys/vm/vfs_cache_pressure"|root' % DirtyBGDRatio) 
+               os.system('echo "echo \"%s\" > /proc/sys/vm/vfs_cache_pressure"|root' % VFSCachePressure) 
 
              message = 'The new configuration has been applied to the system.'
              showMessage(message)
@@ -269,15 +271,16 @@ class MyMainWindow(QtGui.QMainWindow):
              message = 'Please wait. Update in progress..'
              showQuickMessage(message)
 
+             ##Read GUI.
              DirtyRatio = self.ui.lineDirtyRatio.text()
              Swappiness = self.ui.lineSwappiness.text()
              DirtyBGDRatio = self.ui.lineDirtyBGDRatio.text()  
              PageCluster = self.ui.linePageCluster.text()
              DirtyExpireCentisecs = self.ui.lineDirtyExpireCentisecs.text()
              DirtyWritebackCentisecs = self.ui.lineDirtyWritebackCentisecs.text()
-             VFSCachePressure = self.ui.lineVFSCachePressure.text()
              LaptopMode = self.ui.lineLaptopMode.text()
-
+             VFSCachePressure = self.ui.lineVFSCachePressure.text()
+                
              if  self.ui.checkBoxKillAllocatingTask.isChecked() == True:
                 KillAllocatingTask = '1'
              else:
@@ -290,7 +293,7 @@ class MyMainWindow(QtGui.QMainWindow):
                 TCPNoMetricsSave = '1'
              else:
                 TCPNoMetricsSave = '0'
-           
+            
              ##Update of the config file.
              if CheckFile(Path, ConfigFile) == True:
                 try:
